@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 3795 2010-11-09 07:12:37Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 3797 2010-11-10 10:43:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
@@ -29,7 +29,8 @@ class _installInitdbWidgetContainer extends _installBaseWidgetContainer
 	const WORK_DIR = 'work_dir';			// 一時ディレクトリ
 	const UPDATE_DIR = 'update';			// 追加スクリプトディレクトリ名
 	const INSTALL_INFO_CLASS = 'InstallInfo';			// インストール情報クラス
-
+	const DEFAULT_LANG		= 'default_lang';					// デフォルト言語
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -168,9 +169,8 @@ class _installInitdbWidgetContainer extends _installBaseWidgetContainer
 			
 			// ##### 初期データ登録 #####
 			if ($ret){
-				// デフォルト値設定
-				
 				// 初期値設定
+				$langId = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_LANG);
 				$serverId = md5($this->gEnv->getRootUrl() . time());		// サーバID
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::CF_SERVER_ID, $serverId);
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::CF_SERVER_URL, $this->gEnv->getRootUrl());
@@ -178,6 +178,7 @@ class _installInitdbWidgetContainer extends _installBaseWidgetContainer
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(M3_TB_FIELD_DB_UPDATE_DT, $now);
 				//if ($ret) $ret = $this->sysDb->updateSystemConfig(self::WORK_DIR, M3_SYSTEM_WORK_DIR_PATH);// 一時ディレクトリ
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::WORK_DIR, $this->gEnv->getWorkDirPath());// 一時ディレクトリ
+				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::DEFAULT_LANG, $langId);// デフォルト言語
 			}
 			// ##### これ以降、DBへのログ出力可能 #####
 			if ($ret){
