@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainDb.php 3908 2010-12-28 03:23:56Z fishbone $
+ * @version    SVN: $Id: blog_mainDb.php 4452 2011-11-14 12:59:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -222,12 +222,12 @@ class blog_mainDb extends BaseDb
 	 * @param int		$limit				取得する項目数
 	 * @param int		$page				取得するページ(1～)
 	 * @param timestamp $now				現在日時(現在日時より未来の投稿日時の記事は取得しない)
-	 * @param string	$keyword			検索キーワード
+	 * @param array		$keywords			検索キーワード
 	 * @param string	$langId				言語
 	 * @param function	$callback			コールバック関数
 	 * @return 			なし
 	 */
-	function searchEntryItemsByKeyword($limit, $page, $now, $keyword, $langId, $callback)
+	function searchEntryItemsByKeyword($limit, $page, $now, $keywords, $langId, $callback)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
@@ -241,14 +241,14 @@ class blog_mainDb extends BaseDb
 		$queryStr .=     'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
 
 		// タイトルと記事を検索
-		if (!empty($keyword)){
-			// 「'"\」文字をエスケープ
-			$keyword = addslashes($keyword);
-			
-			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+		if (!empty($keywords)){
+			for ($i = 0; $i < count($keywords); $i++){
+				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
+				$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+			}
 		}
 		
 		// 公開期間を指定
@@ -262,17 +262,17 @@ class blog_mainDb extends BaseDb
 		$params[] = $now;
 		
 		$queryStr .=  'ORDER BY be_regist_dt desc limit ' . $limit . ' offset ' . $offset;
-		$this->selectLoop($queryStr, $params, $callback, null);
+		$this->selectLoop($queryStr, $params, $callback);
 	}
 	/**
 	 * 検索条件のエントリー項目数を取得(表示用)
 	 *
 	 * @param timestamp $now				現在日時(現在日時より未来の投稿日時の記事は取得しない)
-	 * @param string	$keyword			検索キーワード
+	 * @param array		$keywords			検索キーワード
 	 * @param string	$langId				言語
 	 * @return int							項目数
 	 */
-	function searchEntryItemsCountByKeyword($now, $keyword, $langId)
+	function searchEntryItemsCountByKeyword($now, $keywords, $langId)
 	{
 		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
 		$params = array();
@@ -283,14 +283,14 @@ class blog_mainDb extends BaseDb
 		$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
 
 		// タイトルと記事を検索
-		if (!empty($keyword)){
-			// 「'"\」文字をエスケープ
-			$keyword = addslashes($keyword);
-			
-			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+		if (!empty($keywords)){
+			for ($i = 0; $i < count($keywords); $i++){
+				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
+				$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+			}
 		}
 		
 		// 公開期間を指定
